package com.zd.airbottle.mapper;

import java.util.List;
import com.zd.airbottle.domain.QpQualificationCertificate;

/**
 * 资质证照Mapper接口
 * 
 * @author zd
 * @date 2022-05-19
 */
public interface QpQualificationCertificateMapper 
{
    /**
     * 查询资质证照
     * 
     * @param id 资质证照主键
     * @return 资质证照
     */
    QpQualificationCertificate selectQpQualificationCertificateById(Long id);

    /**
     * 查询资质证照列表
     * 
     * @param qpQualificationCertificate 资质证照
     * @return 资质证照集合
     */
    List<QpQualificationCertificate> selectQpQualificationCertificateList(QpQualificationCertificate qpQualificationCertificate);

    /**
     * 新增资质证照
     * 
     * @param qpQualificationCertificate 资质证照
     * @return 结果
     */
    int insertQpQualificationCertificate(QpQualificationCertificate qpQualificationCertificate);

    /**
     * 修改资质证照
     * 
     * @param qpQualificationCertificate 资质证照
     * @return 结果
     */
    int updateQpQualificationCertificate(QpQualificationCertificate qpQualificationCertificate);

    /**
     * 删除资质证照
     * 
     * @param id 资质证照主键
     * @return 结果
     */
    int deleteQpQualificationCertificateById(Long id);

    /**
     * 批量删除资质证照
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteQpQualificationCertificateByIds(Long[] ids);
}
